function [Equiv,Equivfreq]=EquivNoise(PSDbb,Ybb,PSDfreq,Ybbfreq)
%This function generates the equivalent noise channel(up to a phase)
%IT IS ASSUMED THAT PSDfreq AND YBBfreq are the same
%
%PSDbb is the baseband noise PSD
%Ybb is the baseband channel
%PSDfreq is the frequencies that are calculated for the noise PSD
%Ybbfreq are the frequencies that are calculated for the channel
Equiv=Ybb./sqrt(PSDbb);
Equivfreq=Ybbfreq;
